@@ -62,7 +62,7 @@ lin_pow <- function(data, con = 1, logT = log,
 
   if (!(is.matrix(data) | is.data.frame(data)))
     stop("data must be a matrix or dataframe")
-  if (is.matrix(data)) data <- as.data.frame(data)
+  data <- as.data.frame(data)
   if (anyNA(data)) stop("NAs present in data")
   if (!is.primitive(logT)) stop("logT should be a (primitive) function,
                                 specifically: log, log2 or log10")
