@@ -355,7 +355,7 @@ sar_threshold <- function(data, mod = "All", interval = NULL, nisl = NULL,
   
   if (!(is.matrix(data) | is.data.frame(data)))
     stop('data must be a matrix or dataframe')
-  if (is.matrix(data)) data <- as.data.frame(data)
+  data <- as.data.frame(data)
   if (anyNA(data)) stop('NAs present in data')
   if (!(is.character(mod) | is.vector(mod))) 
     stop("mod should be character vector")
